Module: Google::Apis::CloudlocationfinderV1alpha

Defined in:
lib/google/apis/cloudlocationfinder_v1alpha.rb,
lib/google/apis/cloudlocationfinder_v1alpha/classes.rb,
lib/google/apis/cloudlocationfinder_v1alpha/service.rb,
lib/google/apis/cloudlocationfinder_v1alpha/gem_version.rb,
lib/google/apis/cloudlocationfinder_v1alpha/representations.rb

Overview

Cloud Location Finder API

Defined Under Namespace

Classes: CloudLocation, CloudLocationFinderService, ListCloudLocationsResponse, ListLocationsResponse, Location, SearchCloudLocationsResponse

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-cloudlocationfinder_v1alpha gem

"0.6.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260325"
VERSION =

Version of the Cloud Location Finder API this client connects to. This is NOT the gem version.

'V1alpha'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'