Class: Google::Apis::CloudlocationfinderV1alpha::CloudLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudlocationfinder_v1alpha/classes.rb,
lib/google/apis/cloudlocationfinder_v1alpha/representations.rb,
lib/google/apis/cloudlocationfinder_v1alpha/representations.rb

Overview

Represents resource cloud locations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CloudLocation

Returns a new instance of CloudLocation.



75
76
77
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 75

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#carbon_free_energy_percentageFloat

Optional. The carbon free energy percentage of the cloud location. This represents the average percentage of time customers' application will be running on carbon-free energy. See https://cloud.google.com/sustainability/ region-carbon for more details. There is a difference between default value 0 and unset value. 0 means the carbon free energy percentage is 0%, while unset value means the carbon footprint data is not available. Corresponds to the JSON property carbonFreeEnergyPercentage

Returns:

  • (Float)


37
38
39
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 37

def carbon_free_energy_percentage
  @carbon_free_energy_percentage
end

#cloud_location_typeString

Optional. The type of the cloud location. Corresponds to the JSON property cloudLocationType

Returns:

  • (String)


42
43
44
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 42

def cloud_location_type
  @cloud_location_type
end

#cloud_providerString

Optional. The provider of the cloud location. Values can be Google Cloud or third-party providers, including AWS, Azure, or Oracle Cloud Infrastructure. Corresponds to the JSON property cloudProvider

Returns:

  • (String)


48
49
50
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 48

def cloud_provider
  @cloud_provider
end

#containing_cloud_locationString

Output only. The containing cloud location in the strict nesting hierarchy. For example, the containing cloud location of a zone is a region. Corresponds to the JSON property containingCloudLocation

Returns:

  • (String)


54
55
56
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 54

def containing_cloud_location
  @containing_cloud_location
end

#display_nameString

Optional. The human-readable name of the cloud location. Example: us-east-2, us-east1. Corresponds to the JSON property displayName

Returns:

  • (String)


60
61
62
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 60

def display_name
  @display_name
end

#nameString

Identifier. Name of the cloud location. Unique name of the cloud location including project and location using the form: projects/project_id/ locations/location/cloudLocations/cloud_location` Corresponds to the JSON propertyname`

Returns:

  • (String)


67
68
69
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 67

def name
  @name
end

#territory_codeString

Optional. The two-letter ISO 3166-1 alpha-2 code of the cloud location. Examples: US, JP, KR. Corresponds to the JSON property territoryCode

Returns:

  • (String)


73
74
75
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 73

def territory_code
  @territory_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



80
81
82
83
84
85
86
87
88
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 80

def update!(**args)
  @carbon_free_energy_percentage = args[:carbon_free_energy_percentage] if args.key?(:carbon_free_energy_percentage)
  @cloud_location_type = args[:cloud_location_type] if args.key?(:cloud_location_type)
  @cloud_provider = args[:cloud_provider] if args.key?(:cloud_provider)
  @containing_cloud_location = args[:containing_cloud_location] if args.key?(:containing_cloud_location)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @territory_code = args[:territory_code] if args.key?(:territory_code)
end