Class: Google::Apis::CloudlocationfinderV1alpha::SearchCloudLocationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudlocationfinder_v1alpha/classes.rb,
lib/google/apis/cloudlocationfinder_v1alpha/representations.rb,
lib/google/apis/cloudlocationfinder_v1alpha/representations.rb

Overview

Message for response to searching cloud locations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchCloudLocationsResponse

Returns a new instance of SearchCloudLocationsResponse.



208
209
210
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_locationsArray<Google::Apis::CloudlocationfinderV1alpha::CloudLocation>

Output only. List of cloud locations. Corresponds to the JSON property cloudLocations



198
199
200
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 198

def cloud_locations
  @cloud_locations
end

#next_page_tokenString

Output only. The continuation token, used to page through large result sets. Provide this value in a subsequent request as page_token in subsequent requests to retrieve the next page. If this field is not present, there are no subsequent results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


206
207
208
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 206

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



213
214
215
216
# File 'lib/google/apis/cloudlocationfinder_v1alpha/classes.rb', line 213

def update!(**args)
  @cloud_locations = args[:cloud_locations] if args.key?(:cloud_locations)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end